changeset 17534:c5f7c4b515a4

en-us: recognized
author timeless@mozdev.org
date Fri, 17 Aug 2012 13:58:19 -0700
parents 927d704d7847
children 63e302be813f
files hgext/bugzilla.py
diffstat 1 files changed, 3 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/hgext/bugzilla.py	Fri Aug 17 13:58:19 2012 -0700
+++ b/hgext/bugzilla.py	Fri Aug 17 13:58:19 2012 -0700
@@ -45,7 +45,7 @@
 email to the Bugzilla email interface to submit comments to bugs.
 The From: address in the email is set to the email address of the Mercurial
 user, so the comment appears to come from the Mercurial user. In the event
-that the Mercurial user email is not recognised by Bugzilla as a Bugzilla
+that the Mercurial user email is not recognized by Bugzilla as a Bugzilla
 user, the email associated with the Bugzilla username used to log into
 Bugzilla is used instead as the source of the comment. Marking bugs fixed
 works on all supported Bugzilla versions.
@@ -53,7 +53,7 @@
 Configuration items common to all access modes:
 
 bugzilla.version
-  This access type to use. Values recognised are:
+  This access type to use. Values recognized are:
 
   :``xmlrpc``:       Bugzilla XMLRPC interface.
   :``xmlrpc+email``: Bugzilla XMLRPC and email interfaces.
@@ -303,7 +303,7 @@
     # Methods to be implemented by access classes.
     #
     # 'bugs' is a dict keyed on bug id, where values are a dict holding
     # updates to bug state. Recognised dict keys are:
     #
     # 'hours': Value, float containing work hours to be updated.
     # 'fix':   If key present, bug is to be marked fixed. Value ignored.
@@ -303,7 +303,7 @@
     #
     # 'bugs' is a dict keyed on bug id, where values are a dict holding
-    # updates to bug state. Recognised dict keys are:
+    # updates to bug state. Recognized dict keys are:
     #
     # 'hours': Value, float containing work hours to be updated.